@@ -4,7 +4,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <msg/msg.h>
 #include <str/str.h>
 #include "auth-lib.h"
 #include "ucspi-proxy.h"
@@ -95,6 +94,7 @@ static void filter_server_data(char* data, ssize_t size)
       resp = parse_label();
       if(resp > 0) {
 	if(!str_diff(&label, &saved_label)) {
+	  log_line(data, size);
 	  /* Check if the response was an OK */
 	  if(!strncasecmp(linebuf.s + resp, "OK ", 3))
 	    accept_client(username.s);
