@@ -4,7 +4,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <msg/msg.h>
 #include <str/str.h>
 #include "auth-lib.h"
 #include "ucspi-proxy.h"
@@ -68,6 +67,7 @@ static void filter_client_data(char* data, ssize_t size)
 static void filter_server_data(char* data, ssize_t size)
 {
   if (saw_command) {
+    log_line(data, size);
     if (!strncasecmp(data, "+OK ", 4)) {
       accept_client(username.s);
       saw_command = 0;
