@@ -12,6 +12,7 @@
 #define NUL '\0'
 
 #define BUFSIZE 4096
+#define MAXLINE 64
 #define CLIENT_IN 0
 #define CLIENT_OUT 1
 extern int SERVER_FD;
@@ -43,10 +44,9 @@ extern int opt_verbose;
 extern pid_t pid;
 extern void write_client(const char*, ssize_t);
 extern void write_server(const char*, ssize_t);
-extern void writes_client(const char*);
-extern void writes_server(const char*);
 extern bool set_filter(int fd, filter_fn filter, eof_fn at_eof);
 extern bool del_filter(int fd);
+extern void log_line(const char* data, ssize_t size);
 
 /* Functions from tcp-connect.c */
 extern int tcp_connect(const char*, const char*, unsigned);
